from flask import render_template, Blueprint, flash, request, redirect, url_for
import requests
from backstage.collections.forms import CollectionCreateForm
from backstage.utils import translate, get_now_time
from backstage.utils.routes import remove_content
from time import sleep


collections_app = Blueprint('collections', __name__)


@collections_app.route('/backstage/collections')
def collection_list():
    response = requests.get('http://127.0.0.1:5000/api/contents?url=/collection')
    if response.status_code == 200:
        return render_template('collections.html',
                               title='家具規劃作品',
                               legend='家具規劃作品列表',
                               collections=response.json(),
                               length=len(response.json()),
                               form=CollectionCreateForm())


@collections_app.route('/backstage/collection/create', methods=['POST'])
def create():
    form = CollectionCreateForm()
    url_name = translate(form.title.data).replace(' ', '_')
    front_matter = '''---
title: "{}"\n\
date: {}\n\
draft: {}\n\
type: "{}"\n\
url: "{}"\n\
image: "/img/collection/{}"\n\
description: "{}"\n\
---'''.format(form.title.data,
              get_now_time(),
              'false',
              'collection',
              '/collection/{}'.format(url_name),
              form.image.data.filename,
              form.description.data)
    data = {'frontMatter': front_matter,
            'name': request.form['title'],
            'type': 'collection'}
    new_response = requests.post('http://127.0.0.1:5000/api/new_content', json=data)
    if new_response.status_code == 200:
        requests.post(
            'http://127.0.0.1:5000/api/upload/static/img?type=collection&filename={}'.format(
                form.image.data.filename), files={'image': form.image.data})
        sleep(0.5)
        return redirect(url_for('editor.editor', url='/collection/{}'.format(url_name)))
    else:
        flash('新增文章失敗', 'danger')
        return redirect(url_for('collections.collection_list'))


@collections_app.route('/backstage/collection/remove', methods=['POST'])
def remove():
    remove_content()
    return redirect(url_for('collections.collection_list'))
